@@ -22,7 +22,7 @@ from neuroml.neuro_lex_ids import neuro_lex_ids
 from scipy.spatial.transform import Rotation
 
 from pyneuroml.pynml import read_neuroml2_file
-from pyneuroml.utils import extract_position_info, rotate_cell, translate_cell_to_coords
+from pyneuroml.utils import extract_position_info, make_cell_upright
 from pyneuroml.utils.plot import (
     DEFAULTS,
     get_cell_bound_box,
@@ -39,6 +39,12 @@ try:
     from vispy.geometry.meshdata import MeshData
     from vispy.scene.visuals import InstancedMesh
     from vispy.util.transforms import rotate
+
+    pynml_in_jupyter = False
+    if app.Application.is_interactive(app):
+        pynml_in_jupyter = True
+        from IPython.display import display
+
 except ImportError:
     logger.warning("Please install optional dependencies to use vispy features:")
     logger.warning("pip install pyneuroml[vispy]")
@@ -473,22 +479,22 @@ def plot_interactive_3D(
 
     # if it isn't a NeuroMLDocument, create one
     if isinstance(nml_model, Cell):
-        logger.info("Got a cell")
+        logger.debug("Got a cell")
         plottable_nml_model = NeuroMLDocument(id="newdoc")
         plottable_nml_model.add(nml_model)
-        logger.info(f"plottable cell model is: {plottable_nml_model.cells[0]}")
+        logger.debug(f"plottable cell model is: {plottable_nml_model.cells[0]}")
         if title is None:
             title = f"{plottable_nml_model.cells[0].id}"
 
     # if it's only a cell, add it to an empty cell in a document
     elif isinstance(nml_model, Morphology):
-        logger.info("Received morph, adding to a dummy cell")
+        logger.debug("Received morph, adding to a dummy cell")
         plottable_nml_model = NeuroMLDocument(id="newdoc")
         nml_cell = plottable_nml_model.add(
             Cell, id=nml_model.id, morphology=nml_model, validate=False
         )
         plottable_nml_model.add(nml_cell)
-        logger.info(f"plottable cell model is: {plottable_nml_model.cells[0]}")
+        logger.debug(f"plottable cell model is: {plottable_nml_model.cells[0]}")
         if title is None:
             title = f"{plottable_nml_model.cells[0].id}"
     elif isinstance(nml_model, NeuroMLDocument):
@@ -520,10 +526,10 @@ def plot_interactive_3D(
         except AttributeError:
             total_segments += len(positions[pop_id])
 
-    logger.info(
+    logger.debug(
         f"Visualising {total_segments} segments in {total_cells} cells in {len(pop_id_vs_cell)} populations"
     )
-    logger.info(
+    logger.debug(
         f"Grouping into mesh instances by diameters at {precision[0]} decimal places"
     )
     # not used later, clear up
@@ -616,15 +622,26 @@ def plot_interactive_3D(
             pass
 
     meshdata = {}  # type: typing.Dict[typing.Any, typing.Any]
-    logger.info("Processing cells")
-    pbar = progressbar.ProgressBar(
-        max_value=total_cells,
-        widgets=[progressbar.SimpleProgress(), progressbar.Bar(), progressbar.Timer()],
-        redirect_stdout=True,
-    )
+    logger.info("Processing %s cells" % total_cells)
+
+    # do not show this pbar in jupyter notebooks
+    if not pynml_in_jupyter:
+        pbar = progressbar.ProgressBar(
+            max_value=total_cells,
+            widgets=[
+                progressbar.SimpleProgress(),
+                progressbar.Bar(),
+                progressbar.Timer(),
+            ],
+            redirect_stdout=True,
+        )
+    else:
+        pbar = None
+
     pbar_ctr = 0
     while pop_id_vs_cell:
-        pbar.update(pbar_ctr)
+        if pbar is not None:
+            pbar.update(pbar_ctr)
         pop_id, cell = pop_id_vs_cell.popitem()
         pos_pop = positions[pop_id]
 
@@ -729,7 +746,9 @@ def plot_interactive_3D(
             # if too many meshes, reduce precision and retry, recursively
             if (len(meshdata.keys()) > precision[1]) and (precision[0] > 0):
                 precision = (precision[0] - 1, precision[1])
-                pbar.finish(dirty=True)
+                if pbar is not None:
+                    pbar.finish(dirty=True)
+
                 logger.info(
                     f"More meshes than threshold ({len(meshdata.keys())}/{precision[1]}), reducing precision to {precision[0]} and re-calculating."
                 )
@@ -753,69 +772,14 @@ def plot_interactive_3D(
             pbar_ctr += 1
 
     if not nogui:
-        pbar.finish()
+        if pbar is not None:
+            pbar.finish()
         create_instanced_meshes(meshdata, plot_type, current_view, min_width)
-        current_canvas.show()
-        app.run()
-
-
-def make_cell_upright(
-    cell: Cell = None,
-    inplace: bool = False,
-) -> Cell:
-    """Use cell's PCA to make it upright
-
-    .. versionadded:: 1.2.13
-
-    :param cell: cell object to translate
-    :type cell: neuroml.Cell
-    :param inplace: toggle whether the cell object should be modified inplace
-        or a copy created (creates and returns a copy by default)
-    :type inplace: bool
-    :returns: new neuroml.Cell object
-    :rtype: neuroml.Cell
-    """
-
-    # Get all segments' distal points
-    segment_points = []
-    segments_all = cell.morphology.segments
-    for segment in segments_all:
-        segment_points.append([segment.distal.x, segment.distal.y, segment.distal.z])
-
-    coords = numpy.array(segment_points)
-    from sklearn.decomposition import PCA
-
-    # Get the PCA components
-    pca = PCA()
-    pca.fit(coords)
-
-    # Get the principal component axes
-    principal_axes = pca.components_
-    # Get the first principal component axis
-    first_pca = principal_axes[0]
-    # y angle needed to eliminate z component
-    y_angle = math.atan(first_pca[2] / first_pca[0])
-    rotation_y = numpy.array(
-        [
-            [math.cos(y_angle), 0, math.sin(y_angle)],
-            [0, 1, 0],
-            [-math.sin(y_angle), 0, math.cos(y_angle)],
-        ]
-    )
-    rotated_pca = numpy.dot(rotation_y, first_pca)
-
-    # z angle needed to eliminate x component
-    z_angle = -math.atan(rotated_pca[0] / rotated_pca[1])
-
-    if z_angle < 0:
-        z_angle += numpy.pi
-
-    logger.info("Making cell upright for visualization")
-    cell = translate_cell_to_coords(cell, inplace=inplace, dest=[0, 0, 0])
-    cell = rotate_cell(
-        cell, 0, y_angle, z_angle, "yzx", relative_to_soma=False, inplace=inplace
-    )
-    return cell
+        if pynml_in_jupyter:
+            display(current_canvas)
+        else:
+            current_canvas.show()
+            app.run()
 
 
 def plot_3D_cell_morphology(
@@ -1073,8 +1037,11 @@ def plot_3D_cell_morphology(
 
     if not nogui:
         create_instanced_meshes(meshdata, plot_type, current_view, min_width)
-        current_canvas.show()
-        app.run()
+        if pynml_in_jupyter:
+            display(current_canvas)
+        else:
+            current_canvas.show()
+            app.run()
     return meshdata
 
 
@@ -1099,7 +1066,7 @@ def create_instanced_meshes(meshdata, plot_type, current_view, min_width):
     total_mesh_instances = 0
     for d, i in meshdata.items():
         total_mesh_instances += len(i)
-    logger.info(
+    logger.debug(
         f"Visualising {len(meshdata.keys())} meshes with {total_mesh_instances} instances"
     )
 
@@ -1146,8 +1113,17 @@ def create_instanced_meshes(meshdata, plot_type, current_view, min_width):
         instance_positions = []
         instance_transforms = []
         instance_colors = []
-        for im in i:
+
+        # if in a notebook, only update once per mesh, but not per mesh
+        # instance
+        if pynml_in_jupyter:
             pbar.update(progress_ctr)
+
+        for num, im in enumerate(i):
+            # if not in a notebook, update for each mesh instance
+            if not pynml_in_jupyter:
+                pbar.update(progress_ctr)
+
             progress_ctr += 1
             prox = im[0]
             dist = im[1]
@@ -1394,7 +1370,10 @@ def plot_3D_schematic(
 
     if not nogui:
         create_instanced_meshes(meshdata, "Detailed", current_view, width)
-        app.run()
+        if pynml_in_jupyter:
+            display(current_canvas)
+        else:
+            app.run()
 
 
 def create_cylindrical_mesh(
